//
// C++ Interface: langPT.h
//
// Description: Backend code for Portuguese laguage support
//
// Author     : Mikael Bhm <micko@bag.org>, (C) 2008
// Translation: Wille Marcel (wille@riseup.net)
//
// Copyright: See COPYING file that comes with this distribution
//
//
/* Defines for Portuguese */

#ifndef LANGPT_H
#define LANGPT_H


#define PT_EN           "Portugus"
#define PT_CTEXT        "Ttulo"
#define PT_CHAPT        "Captulos automticos"
#define PT_PREVD        "Pr-visualizao"
#define PT_LBL50        "Inicia o DVD com:"
#define PT_BTGEN2       "Cancelar"
#define PT_BTSTAR       "Iniciar"
#define PT_END          "Fim"
#define PT_L            "Baixo"
#define PT_M            "Mdio"
#define PT_H            "Alto"
#define PT_OK           "OK"
#define PT_QT           "Sair"

/* Buttons on main menu Size is a bit critical */
#define PT_QTMAN        "       Sair"  
#define PT_ABMAN        "Sobre ManDVD"
#define PT_BTSAVE       " Salvar Projeto"

#define PT_BRN          "Gravar"
#define PT_EXTR         "Extrair"
#define PT_GEN          "Gerar"
#define PT_NXT          "Prximo"
#define PT_PRV          "Anterior"
#define PT_TB95         "Confirmar"
#define PT_CHG          "Mudar"
#define PT_RM           "Remover"
#define PT_CHAP         "Captulo"
#define PT_OPTIONS      "Opes"
#define PT_CLOSE        "Fechar"
#define PT_BTGEN2_2     "Console"
#define PT_LBL2_12      "Partir"
#define PT_LBL2_49      "De"
#define PT_LBL1_2_2     "Para"
#define PT_LBL1_31_2    "Tamanho"
#define PT_TABO         "Ordem de tabulao"
#define PT_BT117_2_2    "Usar slide anterior"
#define PT_BT170        "Opes"
#define PT_BT117_2      "Imagem de Fundo"
#define PT_LBL1_48      "Escolha uma cor de fundo ou uma imagem."
#define PT_LBL1_6       "Aviso no utilize esta funo se voc tiver uma verso da QT > 3.3.4. Isto pode gerar um erro na renderizao do menu. A Trolltech ir corrigir isso na verso 3.3.7"


#define PT_BTGRPRIO      "Prioridade de execuo"
#define PT_TBT_71        "Diretrio do projeto"
#define PT_LV1CT1        "Caminho"
#define PT_LV1CT2        "Codificando"
#define PT_LV1CT3        "Captulos"
#define PT_LV1CT4        "Bitrate do udio"
#define PT_LV1CT5        "Formato"
#define PT_LV1CT6        "Boto de endereo"
#define PT_LV2CT1        "Caminho"

#define PT_BTMOPT        "Ajustar vdeo no udio"
#define PT_TB168_2       "Abrir um arquivo de projeto"
#define PT_BTOPEN        "Abrir projeto"
#define PT_TL1_47        "Novo projeto"
#define PT_TL1_47_2      "Abrir um projeto"
#define PT_RNWA          "Limpar menu"
#define PT_1_46          "Voc pode adicionar efeitos ao seu vdeo. Alguns deles so animados, por exemplo um redemoinho. Depois de selecionar o(s) efeito(s), clique no boto \"Gerar\". Aviso: O processo pode demorar e no  possvel cancel-lo. Os efeitos so aplicados somente aos primeiros e ltimos frames selecionados."

#define PT_TB165         "Gerar"
#define PT_BTEAN         "Efeitos"
#define PT_BTGP63        "Pincel"
#define PT_TLBL2_9_2     " Posio vertical da legenda em relao  altura da tela."
#define PT_TLBL1_45      "Para cortar um trecho, selecione os pontos de incio e de fim, em seguida, clique no boto da tesoura."

#define PT_BTIMP         "Importar EDL"
#define PT_BTCUT         "Cortar um trecho deste vdeo"        
#define PT_LBL1_7        "Adicionar ou Modificar vdeos ao DVD"
#define PT_LBL1_7_2      "Edio e Ajustes"
#define PT_LBL1_7_2_2    "Outros"
#define PT_DEINT         "Desentrelaar vdeo. Melhor para telas LCD."
#define PT_TLBL1_42      "Tamanho do pincel"
#define PT_GIMPE         "Editar com o Gimp"
#define PT_GIMPM         "Modificar com o Gimp"
#define PT_EXTRACT       "Extrair uma imagem do vdeo"

#define PT_1_41          "Legenda"
#define PT_BTEDITSS      "Criar / Modificar"
#define PT_LBL1_39_3     "Altura"
#define PT_LBL1_39_4     "Largura"

#define PT_LBL3_6        "A/V Sync  a sincronizao do udio e do vdeo. Se no estiverem devidamente sincronizados, os sons no iro acompanhar a ao presente na imagem. Voc pode ajustar a sincronizao utilizando o controle A/V Sync."

#define PT_BTGS_2        "Efeitos de vdeo"
#define PT_L2_10_3_2_2   "Contraste"
#define PT_L2_10_3_2     "Brilho"
#define PT_L2_10_3       "Durao"
#define PT_LBL1_37       "Este recurso ir tentar remover um logotipo, como aqueles utilizados por canais de TV, do seu vdeo. Os resultados podem variar. Selecione as coordenadas de localizao e tamanho do logotipo."

#define PT_LBL1_37_2     "Estes controles permitem ajustar o brilho e contraste do seu vdeo. Mova os controles para a esquerda para diminuir, e para direita para aumentar a atuao do efeito."

#define PT_LBL1_37_2_2   "Este recurso inverte a posio horizontal do vdeo, criando uma imagem espelhada."
#define PT_LBL1_37_2_2_2 "Este recurso diminui os rudos na imagem, tornando esta mais suave e mais fiel  verso original."
#define PT_CBOX5         "Pr-visualizar a seleo."
#define PT_LBL1_34       "Adicionar texto"
#define PT_TB_117        "Cor de fundo"
#define PT_LBL1_33       "Escolher uma fonte para a legenda"
#define PT_LBL2_9        "Tamanho da fonte em relao  altura da tela."
#define PT_OPT1          "Mscara selecionada"
#define PT_OPT2          "Mscara clicada"
#define PT_BTMASKE       "Edio de mscara"
#define PT_BTFORCE       "Forar recodificao"
#define PT_BTSUBC_2      "Remover todos os captulos"
#define PT_LBL1_32_2     "Ajuste os parmetros e depois escolha a verso original ou a modificada da imagem para importar."
#define PT_RBT3_2        "Modificada"
#define PT_RBT3          "Original"
#define PT_LBL1_14       "Da imagem"
#define PT_LBL1_14_2     "Para imagem"
#define PT_BTCCT_2       "Modificar a cor do ttulo para esta imagem"
#define PT_LBL1_30       "Aqui voc pode adicionar legendas para seu vdeo."
#define PT_BTG_3         "Criar uma imagem ISO"
#define PT_BTGSUB        "Gerenciamento de legendas"
#define PT_LBL1_28       "Qualidade final para os vdeos codificados. Vdeos com maior qualidade utilizam mais espao em disco."
#define PT_LBL1_27       "Defina a ordem de navegao para os itens do seu menu."
#define PT_BTMODT        "Modificar ttulo"

#define PT_LBL1_26         "Voc pode renomear o captulo para que seja exibido um outro nome no menu do DVD."
#define PT_BT_RENCH        "Renomear captulo"
#define PT_IDTPG           "Adicionar mdia"
#define PT_ACUOPL          "Pr-visualizao da fonte"
#define PT_BTIMS2_2        "Importar parmetro"
#define PT_LBL1_25         "Durao do slide (segundos)"
#define PT_LBL2_3          "Transio em cada slide"
#define PT_LBL1_25_2       "Durao da transio (seg.)"
#define PT_BTAC2_2         "Alterar um captulo"
#define PT_BTAINTRO        "Adicionar um vdeo de introduo ao DVD"
#define PT_LBLl3_2         "Nesta etapa, voc ir inserir todos os vdeos e slideshows a serem apresentados no DVD. Voc pode tambm definir captulos em cada vdeo. \n\nDuplo clique nos vdeos listados abaixo para pr-visualiz-los."

#define PT_LBL1_20         "Seu boto do menu pode ser tanto algum texto, por exemplo o nome do vdeo, como uma imagem. Defina o que voc ir utilizar como boto com os controles abaixo."

#define PT_LBL2_6          "Se voc deseja usar uma imagem como boto, defina uma imagem abaixo. Recomenda-se utilizar imagens no muito grandes."
#define PT_LBL1_9          "<b>Informao do arquivo</b>"
#define PT_LBL4_2          "<b>Endereo do vdeo :</b>"
#define PT_LBL1_18         "Vdeo no recodificado"
#define PT_LBL1_18_2       "Vdeo recodificado"
#define PT_LBL1_3          "Ttulo do vdeo"
#define PT_ADDVP           "Adicione um vdeo ao seu projeto"
#define PT_BTCRSLIDES      "Criar um slideshow"
#define PT_BTSELVI         "Remover vdeo selecionado"
#define PT_BTDEFCH         "Definir captulos"
#define PT_LBL3            "Nesta etapa, voc ir customizar o menu do seu DVD. Voc pode criar e modificar o fundo do menu, escolher a fonte e as cores de destaque dos botes."

#define PT_LBL4            "Escolher fundo"
#define PT_BTCWALL         "Imagem de fundo"
#define PT_BTCWALLUNI      "Cor de fundo"
#define PT_BTANIMEBG       "Fundo animado"
#define PT_LBL3_3          "Cor da fonte do menu"
#define PT_BTFONT          "Fonte do menu"
#define PT_COL_1           "Cor do texto no menu"
#define PT_COL_2           "Cor do texto selecionado"
#define PT_COL_3           "Cor do texto clicado"
#define PT_LBL2_4          "Escolha uma trilha sonora para o seu menu principal"
#define PT_BTFMUS          "Importar trilha sonora"
#define PT_BTMIRRH         "Espelhar horizontalmente"
#define PT_BTMIRRV         "Espelhar verticalmente"
#define PT_LBL1_2          "Adicione cada vdeo listado abaixo ao menu. Use os sliders para definir a posio do boto e, em seguida, confirme a posio.  recomendvel posicionar os botes dentro da borda vermelha. Voc tambm pode escolher o que o seu player de DVD far ao final da reproduo de cada vdeo."

#define PT_BTADDFMF        "Adicionar vdeo ao menu"
#define PT_BTVALBT         "Confirmar posio do boto"
#define PT_LBL1_10         "Quando este vdeo terminar..."

#define PT_LBL1_12         "<p align=\"center\"><b>Mensagem de Alerta!</b></p><p><center>Cuidado! Se voc no tem certeza se os seus arquivos MPEG j esto com o udio codificados no formato AC3,  uma boa idia forar a recodificao do seu projeto em AC3. Alguns players de DVD aceitam apenas este formato de udio! <br />  recomendado tambm desentrelaar seu vdeo, caso pretenda reproduzi-lo em TV's de LCD ou de Plasma. Voc pode fazer isto no \"Menu de Opes\", logo abaixo. A operao de desentrelaamento pode demorar um longo tempo.</center></p> "

#define PT_BTGDVDS         "Gerar estrutura do DVD"
#define PT_BTWRES          "Assista o resultado"
#define PT_BTBDVD          "Gravar DVD"
#define PT_BK3B            "Gravar DVD com K3b"
#define PT_LBL2            "<p><b>Diretrio de destino do DVD:</b>"
#define PT_CONS            "Mostrar / Esconder console"
#define PT_LBL1_5          "<b>CUIDADO!</b> Antes de voc iniciar o processo de gravao, por favor, insira um DVD no drive. De outra forma, nenhum dado ser gravado."

#define PT_LBL1_11         "Gravador de DVD"
#define PT_M_1             "<p align=\"center\"><b>Estamos gravando seu DVD... Por favor, seja paciente.</b></p>"
#define PT_LBL1_17         "Por favor, selecione as opes do seu slideshow, depois clique em <b>Iniciar</b> para iniciar o processamento. Por favor, lembre-se que esta operao requer um <b>longo</b> tempo para ser concluda, principalmente quando se tem muitos slides e transies."

#define PT_BTAFFF          "Fade out na ltima imagem"
#define PT_QREN            "Renderizao em alta qualidade (mais lenta)"
#define PT_ADDP            "Adicionar imagem"
#define PT_IFLD            "Importar pasta"
#define PT_ADDST           "Adicionar trilha sonora"
#define PT_SFNT            "Selecionar fonte"
#define PT_SFCOL           "Cor da fonte"
#define PT_LBL2_5          "Selecionar imagem"
#define PT_LBL1_15_2       "Durao da transio (segundos)"
#define PT_LBL1_15         "Durao da imagem (segundos)"
#define PT_LBL1_16         "Ttulo (vazio para nada)"
#define PT_BTADDCH         "Adicionar captulo"
#define PT_BTRMCH          "Remover captulo"
#define PT_SHVID           "Mostrar vdeo"
#define PT_LBL1_8          "Digite (hora : minuto : segundo) do captulo."
#define PT_LBL4_3          "Incio (segundos)"
#define PT_LBL4_3_2        "Durao (segundos)"
#define PT_CDADDM          "Adicionar uma mscara na imagem de fundo"
#define PT_LBL1_19         "Uma mscara  uma imagem (720x576 pixels) que contm reas transparentes. Ela pode ser colocada sobre o vdeo para permitir alguns efeitos interessantes."

#define PT_LBL5_2          "Progresso da importao"
#define PT_LOOPA           "Animao do menu em loop"
#define PT_LBL1_22         "Repetir vdeo n vezes"
#define PT_3_4             "Qualidade de sada"
#define PT_ACH             "Captulo automtico"
#define PT_ACHS            "Captulos automticos"
#define	PT_AC3		   "Forar recodificao do udio AC3"
#define	PT_NOAC3	   "No"
#define PT_FAC3		   "Forar AC3"
#define PT_LBL1_24	   "Durao (min)"
#define PT_VDIMP	   "Importar vdeo"
#define PT_ANTB		   "Nmero imagem : "
#define PT_ANTF		   "Primeira imagem: 0"
#define PT_ANTL		   "ltima imagem: "
#define PT_SET		   "Configurao"


#define PT_TBLMSG0         "Este processo no inicia: "
#define PT_TBLMSG1         "O nmero mximo de vdeos  20."
#define PT_TBLMSG2         "Por favor, adicione no mnimo um vdeo ou slideshow."
#define PT_TBLMSG3         "Se voc voltar, todas as modificaes sero perdidas.\n\nVoltar?"
#define PT_TBLMSG4         "Por favor, escolha um fundo para seu menu."
#define PT_TBLMSG5         "Seu projeto excede a capacidade do DVD."
#define PT_TBLMSG6         "Por favor, escolha um ttulo para seu vdeo."
#define PT_TBLMSG7         "Seu menu deve ter uma entrada para cada vdeo."
#define PT_TBLMSG8         "Sem permisso para criar arquivos.\n\nVoc tem permisso de escrita no diretrio escolhido para o seu projeto?"
#define PT_TBLMSG9         "Por favor, escolha um diretrio para o projeto."
#define PT_TBLMSG10        "A codificao falhou. Abra o console para mais detalhes."
#define PT_TBLMSG11        "Erro durante a gerao do menu. Cheque o console para mais detalhes."
#define PT_TBLMSG12        "Sucesso! Seu DVD est pronto!"
#define PT_TBLMSG13        "DVD Author retornou um Internal error. Cheque o console para mais detalhes."
#define PT_TBLMSG14        "Por favor, selecione seu gravador de DVD."
#define PT_TBLMSG15        "Gravao finalizada com sucesso!"
#define PT_TBLMSG16        "A gravao falhou.\n\n Voc selecionou o gravador de DVD correto?"
#define PT_TBLMSG17        "Tem certeza de que deseja sair?\n No esquea de salvar o seu projeto!"
#define PT_TBLMSG18        "Voc quer mesmo cancelar a criao deste slideshow?"
#define PT_TBLMSG19        "Cada slideshow tem um limite de 100 imagens."
#define PT_TBLMSG20        "Por favor, adicione no mnimo uma imagem para o seu slideshow."
#define PT_TBLMSG21        "A criao do slideshow est finalizada!\n\nVoc gostaria de assisti-lo?"
#define PT_TBLMSG22        "Voc quer inserir este slideshow no seu projeto de DVD?"
#define PT_TBLMSG23        "A criao do slideshow falhou.\n\nCheque o console para mais detalhes."
#define PT_TBLMSG24        "Voc no escolheu trilha sonora.  Prosseguir?"
#define PT_TBLMSG25        "Por favor, escolha um vdeo."
#define PT_TBLMSG26        "Erro na extrao de imagens do vdeo."
#define PT_TBLMSG27        "OS vdeos selecionados devem ter de 25 a 30fps."
#define PT_TBLMSG28        "O ponto de incio deve ser anterior ao ponto final."
#define PT_TBLMSG29        "O ponto final deve ser posterior ao ponto de incio."
#define PT_TBLMSG30        "Adicionar mdia"
#define PT_TBLMSG31        "Parmetros do menu"
#define PT_TBLMSG32        "Criao do Menu"
#define PT_TBLMSG33        "Criao do DVD"
#define PT_TBLMSG34        "Criar um slideshow com fotos"
#define PT_TBLMSG35        "Criar um fundo animado"
#define PT_TBLMSG36        "Parabns, seu arquivo com"
#define PT_TBLMSG37        "Erro encontrado durante a criao da imagem ISO."
#define PT_TBLMSG38        "<p>Erro! O intervalo  menor do que ou igual  durao do vdeo</p>Isto no  aceitvel."
#define PT_TBLMSG39        "Projeto salvo."
#define PT_TBLMSG40        "Sem transio"
#define PT_TBLMSG41        "Fade out"
#define PT_TBLMSG42        "Fade in"
#define PT_TBLMSG43        "Mix fade"
#define PT_TBLMSG44        "Entrar da dir. p/ esquerda"
#define PT_TBLMSG45        "Entrar da esq. p/ direita"
#define PT_TBLMSG46        "Entrar de baixo p/ cima"
#define PT_TBLMSG47        "Entrar de cima p/ baixo"
#define PT_TBLMSG48        "Zoom"
#define PT_TBLMSG49        "Double"
#define PT_TBLMSG50        "Up and down"
#define PT_TBLMSG51        "Transio aleatria"
#define PT_TBLMSG52        "<i>Tamanho total dos arquivos : </i>"
#define PT_TBLMSG53        "Retornar para o menu"
#define PT_TBLMSG54        "Codificar vdeo"
#define PT_TBLMSG55        "Codificao global do vdeo"
#define PT_TBLMSG56        "Gerar arquivo do menu"
#define PT_TBLMSG57        "Gerar arquivo do DVD Author"
#define PT_TBLMSG58        "Finalizao do projeto"
#define PT_TBLMSG59        "Tocar uma vez"
#define PT_TBLMSG60        "Som em loop"
#define PT_TBLMSG61        "Sim"
#define PT_TBLMSG62        "No"
#define PT_TBLMSG63        "Sobre "
#define PT_TBLMSG64        "Este programa foi originalmente criado por Gibault Stphane (FR).\nManuteno actual a cargo de Mikael Bhm (SE).\n\nEste software pode criar discos de DVD que podem ser reproduzidos em leitores normais.\nPor favor, envie relatrios de bugs atravs da homepage.\nTraduo para Ingls (PORTUGUS) por: Wille Marcel (wille@riseup.net).\n\nA pagina do homemDVD:"
 
#define PT_TBLMSG65        "Abrir o arquivo"
#define PT_TBLMSG66        "Escolha um arquivo de vdeo para importar"
#define PT_TBLMSG67        "Escolha um arquivo de imagem para importar: "
#define PT_TBLMSG68        "Ateno! O vdeo precisa estar sendo reproduzido quando o boto \"Adicionar Captulo\"<br />for pressionado.<u>Vdeo> selecionado:</u> <i><b>"

#define PT_TBLMSG69        "Selecione um arquivo de udio para importar"
#define PT_TBLMSG70        "Selecione onde seu projeto de DVD ser salvo"
#define PT_TBLMSG71        "Pic uma cor"
#define PT_TBLMSG72        "Selecione um ttulo para importar"
#define PT_TBLMSG73        "Selecione uma fonte para importar"
#define PT_TBLMSG74        "Abrir um projeto do ManDVD"
#define PT_TBLMSG75        "Codificando informao em "
#define PT_TBLMSG76        " MB</B><br />Tamanho mximo  aprox. "

#endif